@@ -267,5 +267,38 @@ class FotoUtil:
         "12-30": [FotoFestival("诸神下降，察访善恶", "犯者男女俱亡")]
     }
 
+    OTHER_FESTIVAL = {
+        "1-1": ["弥勒菩萨圣诞"],
+        "1-6": ["定光佛圣诞"],
+        "2-8": ["释迦牟尼佛出家"],
+        "2-15": ["释迦牟尼佛涅槃"],
+        "2-19": ["观世音菩萨圣诞"],
+        "2-21": ["普贤菩萨圣诞"],
+        "3-16": ["准提菩萨圣诞"],
+        "4-4": ["文殊菩萨圣诞"],
+        "4-8": ["释迦牟尼佛圣诞"],
+        "4-15": ["佛吉祥日"],
+        "4-28": ["药王菩萨圣诞"],
+        "5-13": ["伽蓝菩萨圣诞"],
+        "6-3": ["韦驮菩萨圣诞"],
+        "6-19": ["观音菩萨成道"],
+        "7-13": ["大势至菩萨圣诞"],
+        "7-15": ["佛欢喜日"],
+        "7-24": ["龙树菩萨圣诞"],
+        "7-30": ["地藏菩萨圣诞"],
+        "8-15": ["月光菩萨圣诞"],
+        "8-22": ["燃灯佛圣诞"],
+        "9-9": ["摩利支天菩萨圣诞"],
+        "9-19": ["观世音菩萨出家"],
+        "9-30": ["药师琉璃光佛圣诞"],
+        "10-5": ["达摩祖师圣诞"],
+        "10-20": ["文殊菩萨出家"],
+        "11-17": ["阿弥陀佛圣诞"],
+        "11-19": ["日光菩萨圣诞"],
+        "12-8": ["释迦牟尼佛成道"],
+        "12-23": ["监斋菩萨圣诞"],
+        "12-29": ["华严菩萨圣诞"]
+    }
+
     def __init__(self):
         pass
